<?php

namespace FiloBlu\Newsletter\Block\Adminhtml\LandingPage\Grid\Renderer;

use Magento\Framework\DataObject;
use Magento\Backend\Block\Widget\Grid\Column\Renderer\AbstractRenderer as AbstractRenderer;

class EditLink extends AbstractRenderer
{
	/**
	 * @var \Magento\Store\Model\StoreManagerInterface
	 */
	protected $_storeManager;
	/**
	 * @var \FiloBlu\Newsletter\Helper\Data
	 */
	protected $_helper;
	protected $_modelLanding;
	/**
	 * @param \Magento\Backend\Block\Context $context
	 * @param array $data
	 */
	public function __construct(
		\Magento\Backend\Block\Context $context,
		\Magento\Store\Model\StoreManagerInterface $storeManager,
		\FiloBlu\Newsletter\Helper\Data $helper,
		\FiloBlu\Newsletter\Model\LandingPage $modelLanding,
		array $data = []
	)
	{
		$this->_storeManager = $storeManager;
		$this->_helper = $helper;
		$this->_modelLanding = $modelLanding;
		parent::__construct($context, $data);
		$this->_authorization = $context->getAuthorization();
	}
	/**
	 * Renders grid column
	 *
	 * @param Object $row
	 * @return sstring
	 */
	public function render(DataObject $row)
	{

		if ($this->_helper->getConfig('general/newsletter_edit_landing') != 0) {

			$storeId = $row->getStoreId();
			$storeUrl = $this->_storeManager->getStore($storeId)->getBaseUrl();
			$landingId = $this->_helper->getConfig('general/newsletter_edit_landing');
			$model = $this->_modelLanding->getLandingPageById($landingId);
			$landingUrlKey = $model->getUrlKey();
			/**
			 * urlencode needed when email has a '+' inside,
			 * which becomes a space in the getRequest
			 * on FiloBlu\Newsletter\Controller\Index\LandingPage class
			 * and the match in the DB fails.
			 */
			$subscriberEmail = urlencode($row->getSubscriberEmail());
			$subscriberId = $row->getSubscriberId();
			$subscriberConfirmCode = $row->getSubscriberConfirmCode();
			
			return '<a href="'
						. $storeUrl
						. $landingUrlKey
						. '?email=' . $subscriberEmail
						. '&id=' . $subscriberId
						. '&confirm_code=' . $subscriberConfirmCode
						. '&store_id=' . $storeId
						. '&_=' . time()
						. '" target="_blank">Edit</a>';

		} else {
			return '';
		}
	}
}